#!/bin/bash
 
#
# Function :
# The script formats launch a backup
#
# Usage : db2backup_offline.sh <dbname>
# - <dbname> Database Name to be backed up. Mandatory
#
 
#set -x
 
# Variable Declaration
. ~/.bashrc
DBNAME=$1                            # Name of the target database
SCRIPT=db2backup_offline             # Script to be launched - NOT USED NOW
WORKDIR=/db2wk/ibm_dba/script        # Path containing the script
LOGDIR=/db2wk/ibm_dba/log            # Path to log in
LOGRET=15                # Log retention in days
DBRET=10                 # Number of database backups to retain on TSM
 
GIORNO=`date +%y%m%d`
ORA=`date +%H%M`
HISTORYLOG=$LOGDIR"/history_"$DBNAME".log"
DETAILEDLOG=$LOGDIR"/"$GIORNO"_"$ORA"_"$SCRIPT"_"$DBNAME".log"
DAILYLOG=$LOGDIR"/status_"$GIORNO".log"
DBNAME="`echo $DBNAME | tr '[a-z]' '[A-Z]'`"
 
# Check sintax
if [ -z "$DBNAME" ];then
   echo "\nUsage : db2bkp.sh <dbname>" | tee -a ${DETAILEDLOG}
   echo "- <dbname> Database Name to be backed up. Mandatory.\n" | tee -a ${DETAILEDLOG}
   exit 99
fi
 
echo sintax_OK | tee -a ${DETAILEDLOG}
 
# Check Instance status
if [[ `ps -ef | grep $(whoami) | grep -c -w db2sysc` -lt 2 ]]; then
   echo `date +%Y-%m-%d` `date +%H:%M` "  W A R N I N G:   Instance" $(whoami) "is NOT active on this node." | tee -a ${DETAILEDLOG}
   exit 99
fi
 
echo instance_OK | tee -a ${DETAILEDLOG}
 
 
# Check Database Alias
if [[ `db2 list db directory|grep alias | grep -c -w $DBNAME` -lt 1 ]]; then
   echo `date +%Y-%m-%d` `date +%H:%M` "  W A R N I N G:   Database" $DBNAME "could not be found on instance" $(whoami) | tee -a ${DETAILEDLOG}
   exit 99
fi
 
echo alias_OK | tee -a ${DETAILEDLOG}
 
# Launch backup
echo ------------------------------------------------------------ | tee -a ${DETAILEDLOG}
echo `date +%Y-%m-%d` `date +%H:%M` "Start" $SCRIPT "for" $DBNAME | tee -a ${DETAILEDLOG}
db2 "CONNECT TO $DBNAME" | tee -a ${DETAILEDLOG}
db2 "QUIESCE DATABASE IMMEDIATE FORCE CONNECTIONS" | tee -a ${DETAILEDLOG}
db2 "UNQUIESCE DATABASE " | tee -a ${DETAILEDLOG}
db2 "CONNECT RESET " | tee -a ${DETAILEDLOG}
db2 "TERMINATE " | tee -a ${DETAILEDLOG}
db2 "DEACTIVATE DB $DBNAME " | tee -a ${DETAILEDLOG}
 
####      force applications delle connessioni      non chiuse   ########
db2 "list applications" |grep -i $DBNAME  | tee -a ${DETAILEDLOG}
db2 "list applications" |grep -i $DBNAME |while read a b c d e f
do
db2 "force applications (" $c " )" | tee -a ${DETAILEDLOG}
print "forzata applicazione " $c  | tee -a ${DETAILEDLOG}
done
sleep 7
 
#########################################################################
 
db2 "BACKUP DATABASE $DBNAME USE TSM WITH 4 BUFFERS BUFFER 4096 PARALLELISM 2 COMPRESS WITHOUT PROMPTING" | tee -a ${DETAILEDLOG}
RC_BKP=$?
 
 
# Check return code backup
if [[ $RC_BKP -eq 0 ]];then
   echo `date +%Y-%m-%d` `date +%H:%M` "Completed" $SCRIPT "for" $DBNAME | tee -a ${DETAILEDLOG}
else
   echo `date +%Y-%m-%d` `date +%H:%M` "  F A I L E D  " $SCRIPT "for" $DBNAME | tee -a ${DETAILEDLOG}
fi
 
# Activate database
db2 "ACTIVATE DATABASE ${DBNAME}" | tee -a ${DETAILEDLOG}
 
# Purge old backup
db2adutl delete full keep ${DBRET} db $DBNAME without prompting  | tee -a ${DETAILEDLOG}
#db2adutl delete full older than ${DBRET} days db $DB without prompting  | tee -a ${DETAILEDLOG}
 
# Delete old script logs
find $LOGDIR -name "*.log" -mtime +15 -print -exec rm {} \;
 
cat $DETAILEDLOG >> $DAILYLOG
cat $DETAILEDLOG >> $HISTORYLOG
 
exit $RC_BKP
